package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppStock;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2025-01-15
 */
public interface IAppStockService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param stockId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppStock selectAppStockByStockId(String stockId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appStock 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppStock> selectAppStockList(AppStock appStock);

    /**
     * 新增【请填写功能名称】
     *
     * @param appStock 【请填写功能名称】
     * @return 结果
     */
    public int insertAppStock(AppStock appStock);

    /**
     * 修改【请填写功能名称】
     *
     * @param appStock 【请填写功能名称】
     * @return 结果
     */
    public int updateAppStock(AppStock appStock);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param stockIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteAppStockByStockIds(String[] stockIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param stockId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppStockByStockId(String stockId);


    public int updateNewLocation(String oldLocation, String newLocation);
    List<AppStock> selectStockByGoodsId(AppStock tMiStock);

    int updateSts(AppStock tMiStock3);
}
